In  ~/esrc/RomWBW-v3.5.1 are the source for the rom we built an emulator
for. Don't change that directory. Id rather keep this a local dir with 
scripts for now. See if you ccan get the ROMs to build with our tools
(um80, ul80). It uses binaries that need to be built to assemble/link.
If we can get it build with our tools then we would have a pip install
only.  See ~/esrc/RomWBW-v3.5.1/Source/*.cmd
Also it will be a good test for our tools if we can build all those
files and have the output compare byte for bytes.s
